==> gaffer_0.52.2.0.orig.tar.gz: gaffer-0.52.2.0/include/GafferUI/ConnectionCreator.h <==
//////////////////////////////////////////////////////////////////////////
//
//  Copyright (c) 2017, Image Engine Design Inc. All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are
//  met:
//
//      * Redistributions of source code must retain the above
//        copyright notice, this list of conditions and the following
//        disclaimer.
//
//      * Redistributions in binary form must reproduce the above
//        copyright notice, this list of conditions and the following
//        disclaimer in the documentation and/or other materials provided with
//        the distribution.
//
//      * Neither the name of John Haddon nor the names of
//        any other contributors to this software may be used to endorse or
//        promote products derived from this software without specific prior
//        written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
//  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
//  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
//  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
//  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//////////////////////////////////////////////////////////////////////////

#ifndef GAFFERUI_CONNECTIONCREATOR_H
#define GAFFERUI_CONNECTIONCREATOR_H

#include "GafferUI/Gadget.h"

namespace Gaffer
{

class Plug;

} // namespace Gaffer

namespace GafferUI
{

class GAFFERUI_API ConnectionCreator : public Gadget
{

	public :

		IE_CORE_DECLARERUNTIMETYPEDEXTENSION( GafferUI::ConnectionCreator, ConnectionCreatorTypeId, Gadget );

		ConnectionCreator( const std::string &name=defaultName<ConnectionCreator>() );
		virtual ~ConnectionCreator();

		/// May be called by the recipient of a drag to figure out if this
		/// ConnectionCreator can set up the connection.
		virtual bool canCreateConnection( const Gaffer::Plug *endpoint ) const = 0;

		/// May be called by the recipient of a drag to set a more appropriate position
		/// and tangent for the connection as the drag progresses within the destination.
		virtual void updateDragEndPoint( const Imath::V3f position, const Imath::V3f &tangent ) = 0;

		/// May be called by the recipient of a drag to create a connection,
		/// allowing this ConnectionCreator to set up the necessary plugs or clean up
		/// potentially outdated connections afterwards.
		virtual void createConnection( Gaffer::Plug *plug ) = 0;

};

IE_CORE_DECLAREPTR( ConnectionCreator )

typedef Gaffer::FilteredChildIterator<Gaffer::TypePredicate<ConnectionCreator>> ConnectionCreatorIterator;
typedef Gaffer::FilteredRecursiveChildIterator<Gaffer::TypePredicate<ConnectionCreator>> RecursiveConnectionCreatorIterator;

} // namespace GafferUI

#endif // GAFFERUI_CONNECTIONCREATOR_H

==> gaffer_0.54.2.0.orig.tar.gz: gaffer-0.54.2.0/include/GafferUI/ConnectionCreator.h <==
//////////////////////////////////////////////////////////////////////////
//
//  Copyright (c) 2017, Image Engine Design Inc. All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are
//  met:
//
//      * Redistributions of source code must retain the above
//        copyright notice, this list of conditions and the following
//        disclaimer.
//
//      * Redistributions in binary form must reproduce the above
//        copyright notice, this list of conditions and the following
//        disclaimer in the documentation and/or other materials provided with
//        the distribution.
//
//      * Neither the name of John Haddon nor the names of
//        any other contributors to this software may be used to endorse or
//        promote products derived from this software without specific prior
//        written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
//  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
//  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
//  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
//  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//////////////////////////////////////////////////////////////////////////

#ifndef GAFFERUI_CONNECTIONCREATOR_H
#define GAFFERUI_CONNECTIONCREATOR_H

#include "GafferUI/Gadget.h"

namespace Gaffer
{

class Plug;

} // namespace Gaffer

namespace GafferUI
{

class GAFFERUI_API ConnectionCreator : public Gadget
{

	public :

		GAFFER_GRAPHCOMPONENT_DECLARE_TYPE( GafferUI::ConnectionCreator, ConnectionCreatorTypeId, Gadget );

		ConnectionCreator( const std::string &name=defaultName<ConnectionCreator>() );
		~ConnectionCreator() override;

		/// May be called by the recipient of a drag to figure out if this
		/// ConnectionCreator can set up the connection.
		virtual bool canCreateConnection( const Gaffer::Plug *endpoint ) const = 0;

		/// May be called by the recipient of a drag to set a more appropriate position
		/// and tangent for the connection as the drag progresses within the destination.
		virtual void updateDragEndPoint( const Imath::V3f position, const Imath::V3f &tangent ) = 0;

		/// May be called by the recipient of a drag to create a connection,
		/// allowing this ConnectionCreator to set up the necessary plugs or clean up
		/// potentially outdated connections afterwards.
		virtual void createConnection( Gaffer::Plug *plug ) = 0;

};

IE_CORE_DECLAREPTR( ConnectionCreator )

typedef Gaffer::FilteredChildIterator<Gaffer::TypePredicate<ConnectionCreator>> ConnectionCreatorIterator;
typedef Gaffer::FilteredRecursiveChildIterator<Gaffer::TypePredicate<ConnectionCreator>> RecursiveConnectionCreatorIterator;

} // namespace GafferUI

#endif // GAFFERUI_CONNECTIONCREATOR_H
